@@ -437,11 +437,26 @@ class PublicationCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
         -a --address=ADDRESS
         -k --key-index=KEY_INDEX
         -t --ttl=TTL
+        -r --resolution=RESOLUTION
+        -s --steps=STEP
         -c --count=COUNT
         -i --interval=INTERVAL
         -m --model=MODEL
+
+    Resolution is one of: 100ms 1s, 10s, 10m
     """
 
+    def _get_resolution(self, arguments):
+        RESOLUTIONS = {
+            "100ms": PublishPeriodStepResolution.RESOLUTION_100_MS,
+            "1s": PublishPeriodStepResolution.RESOLUTION_1_S,
+            "10s": PublishPeriodStepResolution.RESOLUTION_10_S,
+            "10m": PublishPeriodStepResolution.RESOLUTION_10_MIN,
+        }
+        resolution = arguments.get("--resolution", None)
+
+        return RESOLUTIONS[resolution] if resolution is not None else None
+
     async def __call__(self, application, arguments):
         from bluetooth_mesh import models
 
@@ -459,6 +474,9 @@ class PublicationCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
                     * 1000
                 )
 
+                resolution = self._get_resolution(arguments) or PublishPeriodStepResolution.RESOLUTION_10_S
+                steps = int(arguments.get("--steps", 6))
+
                 status = await model.set_publication(
                     address,
                     0,
@@ -466,8 +484,8 @@ class PublicationCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
                     publication_address=int(arguments["--address"], 16),
                     app_key_index=int(arguments["--key-index"]),
                     TTL=int(arguments["--ttl"]),
-                    publish_step_resolution=PublishPeriodStepResolution.RESOLUTION_10_S,
-                    publish_number_of_steps=6,
+                    publish_step_resolution=resolution,
+                    publish_number_of_steps=steps,
                     retransmit_count=int(arguments["--count"]),
                     retransmit_interval=interval,
                     model=getattr(models, arguments["--model"]),
@@ -770,6 +788,24 @@ class LightCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
             print("{}: {}".format(node.name, param))
 
 
+class LightRangeCommand(ModelGetCommandMixin, NodeSelectionCommandMixin, Command):
+    USAGE = """
+        Usage:
+            %(cmd)s <uuid>...
+            %(cmd)s -g <groups>...
+
+        Options:
+            -g --groups
+        """
+    ELEMENT = 0
+    CMD = "light_range"
+    MODEL = LightLightnessClient
+    PARAMETER = "lightness_range"
+
+    def format(self, data):
+        return "min={}, max={}".format(data["range_min"], data["range_max"])
+
+
 class NetworkTransmissionCommand(ModelCommandMixin, NodeSelectionCommandMixin, Command):
     USAGE = """
         Usage:
@@ -1090,6 +1126,7 @@ class MeshCommandLine(*application_mixins, Application):
         AclCommand,
         PublicationCommand,
         LightExtendedControllerCommand,
+        LightRangeCommand,
     ]
 
     COMPANY_ID = 0xFEE5
@@ -1236,11 +1273,16 @@ def main():
         Options:
             -l --login <login>             User login to platform service (email)
             -p --password <password>       User password to platform service (!unsecured!)
-            -n --project <project>         Project name to be loaded from platform
+            -n --project <project>         Project name or id to be loaded from platform
 
             --partner <partner>            Partner identifier [default: silvair]
             --env <environment>            Environment: dev,preprod or prod [default: preprod]
 
+            --auth0-client-id <client_id>  Auth0 client id
+            --auth0-secret <secret>        Auth0 secret (!unsecured!)
+            --auth0-domain <domain>        Auth0 domain name
+            --serial-number <serial_num>   Gateway serial number
+
             -d --debug
             -h --help                      Show this help message and exit
             --version                      Show version and exit
